Module bytes

Module bytes 

Byte oriented array utils.

This module provides various utilities to encode and decode byte-aware date types from and into arrays.

Also see the encoding sub-module for converting data types into byte arrays, and decoding sub-module for converting byte arrays into data types.

Modules

decoding
encoding

Structs

BigEndian
A wrapper type for big-endian integer parsing.
LittleEndian
A wrapper type for little-endian integer parsing.
NativeEndian
A wrapper type for native-endian integer parsing.

Type Aliases

Be
Le
Ne
Net