NativeEndian

Struct NativeEndian 

pub struct NativeEndian<T>(pub T);
A wrapper type for native-endian integer parsing.

Notice that this encoding is not portable across different platforms with different endianness. Thus this wrapper should not be used for data that needs to be shared across different platforms.

Tuple Fields

0: T