pub struct NativeEndian<T>(pub T);Expand description
A wrapper type for native-endian integer parsing.
Notice that this encoding is not portable across different platforms with different endianness. Thus this wrapper should not be used for data that needs to be shared across different platforms.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Clone> Clone for NativeEndian<T>
impl<T: Clone> Clone for NativeEndian<T>
Sourcefn clone(&self) -> NativeEndian<T>
fn clone(&self) -> NativeEndian<T>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug> Debug for NativeEndian<T>
impl<T: Debug> Debug for NativeEndian<T>
Sourceimpl<T: Default> Default for NativeEndian<T>
impl<T: Default> Default for NativeEndian<T>
Sourcefn default() -> NativeEndian<T>
fn default() -> NativeEndian<T>
Returns the “default value” for a type. Read more
Sourceimpl FromByteArray for NativeEndian<f32>
impl FromByteArray for NativeEndian<f32>
Sourceimpl FromByteArray for NativeEndian<f64>
impl FromByteArray for NativeEndian<f64>
Sourceimpl FromByteArray for NativeEndian<i128>
impl FromByteArray for NativeEndian<i128>
Sourceimpl FromByteArray for NativeEndian<i16>
impl FromByteArray for NativeEndian<i16>
Sourceimpl FromByteArray for NativeEndian<i32>
impl FromByteArray for NativeEndian<i32>
Sourceimpl FromByteArray for NativeEndian<i64>
impl FromByteArray for NativeEndian<i64>
Sourceimpl FromByteArray for NativeEndian<i8>
impl FromByteArray for NativeEndian<i8>
Sourceimpl FromByteArray for NativeEndian<u128>
impl FromByteArray for NativeEndian<u128>
Sourceimpl FromByteArray for NativeEndian<u16>
impl FromByteArray for NativeEndian<u16>
Sourceimpl FromByteArray for NativeEndian<u32>
impl FromByteArray for NativeEndian<u32>
Sourceimpl FromByteArray for NativeEndian<u64>
impl FromByteArray for NativeEndian<u64>
Sourceimpl FromByteArray for NativeEndian<u8>
impl FromByteArray for NativeEndian<u8>
Sourceimpl<T: Hash> Hash for NativeEndian<T>
impl<T: Hash> Hash for NativeEndian<T>
Sourceimpl IntoByteArray for NativeEndian<f32>
impl IntoByteArray for NativeEndian<f32>
Sourceimpl IntoByteArray for NativeEndian<f64>
impl IntoByteArray for NativeEndian<f64>
Sourceimpl IntoByteArray for NativeEndian<i128>
impl IntoByteArray for NativeEndian<i128>
Sourceimpl IntoByteArray for NativeEndian<i16>
impl IntoByteArray for NativeEndian<i16>
Sourceimpl IntoByteArray for NativeEndian<i32>
impl IntoByteArray for NativeEndian<i32>
Sourceimpl IntoByteArray for NativeEndian<i64>
impl IntoByteArray for NativeEndian<i64>
Sourceimpl IntoByteArray for NativeEndian<i8>
impl IntoByteArray for NativeEndian<i8>
Sourceimpl IntoByteArray for NativeEndian<u128>
impl IntoByteArray for NativeEndian<u128>
Sourceimpl IntoByteArray for NativeEndian<u16>
impl IntoByteArray for NativeEndian<u16>
Sourceimpl IntoByteArray for NativeEndian<u32>
impl IntoByteArray for NativeEndian<u32>
Sourceimpl IntoByteArray for NativeEndian<u64>
impl IntoByteArray for NativeEndian<u64>
Sourceimpl IntoByteArray for NativeEndian<u8>
impl IntoByteArray for NativeEndian<u8>
Sourceimpl<T: Ord> Ord for NativeEndian<T>
impl<T: Ord> Ord for NativeEndian<T>
Sourcefn cmp(&self, other: &NativeEndian<T>) -> Ordering
fn cmp(&self, other: &NativeEndian<T>) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T: PartialEq> PartialEq for NativeEndian<T>
impl<T: PartialEq> PartialEq for NativeEndian<T>
Sourceimpl<T: PartialOrd> PartialOrd for NativeEndian<T>
impl<T: PartialOrd> PartialOrd for NativeEndian<T>
impl<T: Copy> Copy for NativeEndian<T>
impl<T: Eq> Eq for NativeEndian<T>
impl<T> StructuralPartialEq for NativeEndian<T>